# Development install

First, clone the repo to your local environment and change directory to the
newly cloned repo.
Then, install the package in development mode.

Recommended:

```bash
uv sync --all-groups
```

For simplicity, the following instructions will be written for `uv` users.

You can also create, activate, and manage your virtual environment manually with `venv`
and `pip` if you prefer, but it's more complicated!

## Uninstall

```bash
uv remove jupyter-xarray-tiler
```
